==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/PolarLineSeriesBase_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PolarBase } from "./PolarBase";
import { PathRenderer } from "./PathRenderer";
import { DefaultFlattener } from "./DefaultFlattener";
import { PolarBaseView } from "./PolarBaseView";
import { Number_$type, Point_$type, markType } from "igniteui-react-core";
import { PolarLinePlanner } from "./PolarLinePlanner";
import { List$1 } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
export let PolarLineSeriesBase = /*@__PURE__*/ (() => {
    class PolarLineSeriesBase extends PolarBase {
        get_zo() {
            return true;
        }
        zt() {
            return true;
        }
        cr() {
            return new PolarLineSeriesBaseView(this);
        }
        qz(a) {
            super.qz(a);
            this.ace = a;
        }
        constructor() {
            super();
            this.acb = null;
            this.acd = null;
            this.acc = null;
            this.acb = new PathRenderer(1, new DefaultFlattener());
            this.acd = new PathRenderer(0);
        }
        acf() {
            return 1;
        }
        get_aci() {
            return false;
        }
        get aci() {
            return this.get_aci();
        }
        get_ack() {
            return false;
        }
        get ack() {
            return this.get_ack();
        }
        aa8(a, b) {
            super.aa8(a, b);
            a.m.clear();
            let c = b.by;
            let d = b.bx;
            let e = b.getEffectiveViewport();
            let f = this.ze != null ? this.ze.count : 0;
            let g = this.zf != null ? this.zf.count : 0;
            let h = Math.min(f, g);
            let i = ((() => {
                let $ret = new PolarLinePlanner();
                $ret.m = (j) => this.yr.a.getScaledAngle1(this.ze.item(j), this.yr.e, this.yr.d);
                $ret.q = h;
                $ret.n = (j) => this.yp.od(this.zf.item(j), this.yr.g, this.yr.f, this.yr.i, this.yr.h);
                $ret.l = this.ic;
                $ret.f = this.zu;
                $ret.b = this.acf();
                $ret.o = (j) => this.acl(a, j);
                $ret.p = (j) => this.acm(a, j);
                $ret.ad = d;
                $ret.ac = e;
                $ret.ae = c;
                $ret.d = this.ack;
                $ret.c = this.aci;
                return $ret;
            })());
            let j = new List$1(Number_$type, 0);
            for (let k = 0; k < h; k++) {
                if (this.acj(k)) {
                    j.add(k);
                }
            }
            if (this.ack && j.count > 0) {
                j.add(j._inner[0]);
            }
            i.x(a.m, j);
        }
        acl(a, b) {
            return a.w._inner[b].x;
        }
        acm(a, b) {
            return a.w._inner[b].y;
        }
        ach() {
            return !this.acg();
        }
        acg() {
            let a = this.da.vx;
            return !a.containsPoint({ $type: Point_$type, x: 0.5, y: 0.5 });
        }
        acj(a) {
            return (this.ze.item(a) >= this.yr.a.l2 && this.ze.item(a) <= this.yr.a.l1 && this.zf.item(a) >= this.yr.b.l2 && this.zf.item(a) <= this.yr.b.l1) || (isNaN_(this.ze.item(a)) || isNaN_(this.zf.item(a)));
        }
        o4(a, b) {
            super.o4(a, b);
            this.acn(b);
        }
        abc(a, b) {
            super.abc(a, b);
            if (this.zu) {
                this.acc = this.acb;
            }
            else {
                this.acc = this.acd;
            }
            this.acc.b = this.acf();
            this.acn(b);
            this.aco(a, b);
        }
    }
    PolarLineSeriesBase.$t = /*@__PURE__*/ markType(PolarLineSeriesBase, 'PolarLineSeriesBase', PolarBase.$);
    return PolarLineSeriesBase;
})();
/**
 * @hidden
 */
export let PolarLineSeriesBaseView = /*@__PURE__*/ (() => {
    class PolarLineSeriesBaseView extends PolarBaseView {
        constructor(a) {
            super(a);
            this.c8 = null;
            this.c8 = a;
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.vx = a;
            this.e.jl = 3;
            this.e.jm = 1;
            this.e.jn = 4;
            this.e.hb = false;
        }
    }
    PolarLineSeriesBaseView.$t = /*@__PURE__*/ markType(PolarLineSeriesBaseView, 'PolarLineSeriesBaseView', PolarBaseView.$);
    return PolarLineSeriesBaseView;
})();

==> igniteui-react-charts-18.7.5-beta.0.tgz: package/esm2015/lib/PolarLineSeriesBase_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PolarBase } from "./PolarBase";
import { PathRenderer } from "./PathRenderer";
import { DefaultFlattener } from "./DefaultFlattener";
import { PolarBaseView } from "./PolarBaseView";
import { Number_$type, Point_$type, markType } from "igniteui-react-core";
import { PolarLinePlanner } from "./PolarLinePlanner";
import { List$1 } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
export let PolarLineSeriesBase = /*@__PURE__*/ (() => {
    class PolarLineSeriesBase extends PolarBase {
        get_zr() {
            return true;
        }
        zw() {
            return true;
        }
        cs() {
            return new PolarLineSeriesBaseView(this);
        }
        qz(a) {
            super.qz(a);
            this.ach = a;
        }
        constructor() {
            super();
            this.ace = null;
            this.acg = null;
            this.acf = null;
            this.ace = new PathRenderer(1, new DefaultFlattener());
            this.acg = new PathRenderer(0);
        }
        aci() {
            return 1;
        }
        get_acl() {
            return false;
        }
        get acl() {
            return this.get_acl();
        }
        get_acn() {
            return false;
        }
        get acn() {
            return this.get_acn();
        }
        abb(a, b) {
            super.abb(a, b);
            a.m.clear();
            let c = b.by;
            let d = b.bx;
            let e = b.getEffectiveViewport();
            let f = this.zh != null ? this.zh.count : 0;
            let g = this.zi != null ? this.zi.count : 0;
            let h = Math.min(f, g);
            let i = ((() => {
                let $ret = new PolarLinePlanner();
                $ret.m = (j) => this.yu.a.getScaledAngle1(this.zh.item(j), this.yu.e, this.yu.d);
                $ret.q = h;
                $ret.n = (j) => this.ys.oe(this.zi.item(j), this.yu.g, this.yu.f, this.yu.i, this.yu.h);
                $ret.l = this.id;
                $ret.f = this.zx;
                $ret.b = this.aci();
                $ret.o = (j) => this.aco(a, j);
                $ret.p = (j) => this.acp(a, j);
                $ret.ad = d;
                $ret.ac = e;
                $ret.ae = c;
                $ret.d = this.acn;
                $ret.c = this.acl;
                return $ret;
            })());
            let j = new List$1(Number_$type, 0);
            for (let k = 0; k < h; k++) {
                if (this.acm(k)) {
                    j.add(k);
                }
            }
            if (this.acn && j.count > 0) {
                j.add(j._inner[0]);
            }
            i.x(a.m, j);
        }
        aco(a, b) {
            return a.w._inner[b].x;
        }
        acp(a, b) {
            return a.w._inner[b].y;
        }
        ack() {
            return !this.acj();
        }
        acj() {
            let a = this.db.v4;
            return !a.containsPoint({ $type: Point_$type, x: 0.5, y: 0.5 });
        }
        acm(a) {
            return (this.zh.item(a) >= this.yu.a.l4 && this.zh.item(a) <= this.yu.a.l3 && this.zi.item(a) >= this.yu.b.l4 && this.zi.item(a) <= this.yu.b.l3) || (isNaN_(this.zh.item(a)) || isNaN_(this.zi.item(a)));
        }
        o5(a, b) {
            super.o5(a, b);
            this.acq(b);
        }
        abf(a, b) {
            super.abf(a, b);
            if (this.zx) {
                this.acf = this.ace;
            }
            else {
                this.acf = this.acg;
            }
            this.acf.b = this.aci();
            this.acq(b);
            this.acr(a, b);
        }
    }
    PolarLineSeriesBase.$t = /*@__PURE__*/ markType(PolarLineSeriesBase, 'PolarLineSeriesBase', PolarBase.$);
    return PolarLineSeriesBase;
})();
/**
 * @hidden
 */
export let PolarLineSeriesBaseView = /*@__PURE__*/ (() => {
    class PolarLineSeriesBaseView extends PolarBaseView {
        constructor(a) {
            super(a);
            this.c8 = null;
            this.c8 = a;
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.vz = a;
            this.e.jm = 3;
            this.e.jn = 1;
            this.e.jo = 4;
            this.e.hc = false;
        }
    }
    PolarLineSeriesBaseView.$t = /*@__PURE__*/ markType(PolarLineSeriesBaseView, 'PolarLineSeriesBaseView', PolarBaseView.$);
    return PolarLineSeriesBaseView;
})();
